#
# spec file for package perl-Mojo-Pg
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mojo-Pg
Name:           perl-Mojo-Pg
Version:        4.27
Release:        1.9
License:        Artistic-2.0
Summary:        Wrapper around DBD::Pg for using PostgreSql with Mojolicious
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SR/SRI/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBD::Pg) >= 3.007004
BuildRequires:  perl(Mojolicious) >= 8.50
BuildRequires:  perl(SQL::Abstract::Pg) >= 1.0
Requires:       perl(DBD::Pg) >= 3.007004
Requires:       perl(Mojolicious) >= 8.50
Requires:       perl(SQL::Abstract::Pg) >= 1.0
%{perl_requires}

%description
Mojo::Pg is a tiny wrapper around DBD::Pg that makes at
http://www.postgresql.org a lot of fun to use with the at
https://mojolicious.org real-time web framework. Perform queries blocking
and non-blocking, use all at
https://www.postgresql.org/docs/current/static/sql.html PostgreSQL has to
offer, generate CRUD queries from data structures, manage your database
schema with migrations and build scalable real-time web applications with
the publish/subscribe pattern.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README.md
%license LICENSE

%changelog
* Wed Mar 16 2022 Tina Müller <timueller+perl@suse.de>
- updated to 4.27
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.27  2022-03-10
  - Fixed a race condition in Mojo::Pg::Migrations that could result in two processes trying to create the same
    migration.
* Thu Sep  9 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.26
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.26  2021-09-08
  - Fixed a bug in Mojo::Pg::PubSub would sometimes miss notifications. (akarelas)
* Sun Feb 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.25
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.25  2021-02-20
  - Moved SQL::Abstract::Pg into a separate distribution.
* Sun Feb  7 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.24
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.24  2021-01-27
  - Fixed Mojolicious 8.72 support.
* Mon Jan  4 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.23
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.23  2020-12-20
  - Updated examples to use signatures.
  - Improved Mojo::Pg::PubSub to handle unknown notifications more gracefully.
* Sat Nov  7 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.22
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.22  2020-11-06
  - Added from_dir method to Mojo::Pg::Migrations. (kiwiroy)
  - Improved Mojo::Pg::Database to handle connection errors more gracefully.
* Mon Oct 26 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.21
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.21  2020-10-25
  - Added reset method to Mojo::Pg.
  - Changed SQL style to use uppercase keywords.
* Sun Oct  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.20
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.20  2020-10-01
  - Fixed fork-safety feature to work with more than one fork.
* Mon Jun  1 2020 Tina Müller <timueller+perl@suse.de>
  updated to 4.19
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.19  2020-05-30
  - Improved .perltidyrc with more modern settings.
  - Fixed validation problem in blog example.
  4.18  2020-01-30
  - Improved support for -json values to be a little more consistent.
* Tue Oct  8 2019 <timueller+perl@suse.de>
- updated to 4.17
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.17  2019-10-07
  - Reverted connection cache optimization from 4.14, because it caused problems
    with some connections closed by the PostgreSQL server.
  - Updated mojo_migrations table created by Mojo::Pg::Migrations to use a
    primary key.
* Thu Sep  5 2019 <timueller+perl@suse.de>
- updated to 4.16
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.16  2019-09-04
  - Updated DBD::Pg requirement to 3.7.4 due to certain JSON features not
    working with older versions.
* Thu Jul 25 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.15
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.15  2019-07-24
  - Improved compatibility with older versions of DBI.
* Tue Jul 23 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.14
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.14  2019-07-22
  - Improved connection cache to be more than an order of magnitude faster for
    blocking queries.
  - Fixed a bug in Mojo::Pg::PubSub where listen/unlisten did not work while
    reconnecting.
* Mon Jan 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.13
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.13  2019-01-20
  - Added support for multi-column joins to SQL::Abstract::Pg. (rsindlin)
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 4.12
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.12  2018-11-24
  - Added reconnect_interval attribute to Mojo::Pg::PubSub. (jberger)
  - Added db method to Mojo::Pg::PubSub. (jberger)
  - Fixed reconnect logic in Mojo::Pg::PubSub. (jberger)
* Fri Nov  9 2018 Jan Engelhardt <jengelh@inai.de>
- Replace useless summary.
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 4.11
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.11  2018-10-18
  - Improved various attributes to use new Mojolicious 8.03 features to avoid
    memory leaks.
* Wed Sep 19 2018 Stephan Kulow <coolo@suse.com>
- updated to 4.10
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
* Fri Aug  3 2018 coolo@suse.com
- updated to 4.09
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
* Wed Jan 31 2018 coolo@suse.com
- updated to 4.08
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.08  2018-01-29
  - Improved on_conflict option of insert and insert_p methods in
    Mojo::Pg::Database with a shortcut for simple conflict targets.
  4.07  2018-01-28
  - Added support for "JOIN" to select and select_p methods in
    Mojo::Pg::Database.
  - Added support for field aliases to select and select_p methods in
    Mojo::Pg::Database.
  - Added support for having option to select and select_p methods in
    Mojo::Pg::Database.
  - Improved on_conflict option of insert and insert_p methods in
    Mojo::Pg::Database with shortcuts for "ON CONFLICT DO UPDATE SET" and
    "ON CONFLICT DO NOTHING".
  - Improved for option of select and select_p methods in Mojo::Pg::Database
    with a shortcut for "FOR UPDATE".
  4.06  2018-01-27
  - Added support for on_conflict option to insert and insert_p methods in
    Mojo::Pg::Database.
  - Updated SQL::Abstract requirement to 1.84.
  - Improved error messages generated by SQL::Abstract::Pg to be compatible with
    SQL::Abstract.
  4.05  2018-01-26
  - Added support for for, group_by, limit, offset and order_by options to
    select and select_p methods in Mojo::Pg::Database.
  - Added module SQL::Abstract::Pg.
* Mon Dec 18 2017 coolo@suse.com
- updated to 4.04
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.04  2017-12-16
  - Added db attribute to Mojo::Pg::Results.
  - Added sql_for method to Mojo::Pg::Migrations.
  - Fixed a bug that could cause connections to be cached for reuse too early.
* Sun Nov  5 2017 coolo@suse.com
- updated to 4.03
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.03  2017-11-04
  - Improved Mojo::Pg::Database to use Mojo::Promise.
* Fri Nov  3 2017 coolo@suse.com
- updated to 4.02
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.02  2017-11-02
  - Added delete_p, insert_p, query_p, select_p and update_p methods to
    Mojo::Pg::Database.
* Fri Jul 21 2017 coolo@suse.com
- updated to 4.01
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.01  2017-07-20
  - Decreased default max_connections from 5 to 1 in Mojo::Pg.
* Fri Jul  7 2017 coolo@suse.com
- updated to 4.0
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  4.0  2017-07-06
  - Added support for sharing the database connection cache between multiple
    Mojo::Pg objects.
  - Added parent attribute to Mojo::Pg.
  - Fixed a bug where automatic migrations would leak database connections.
* Fri Jun  2 2017 coolo@suse.com
- updated to 3.06
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  3.06  2017-06-01
  - Updated example application with tests.
  - Improved Mojo::Pg to be a little less noisy by deactivating PrintWarn by
    default.
* Fri Mar 17 2017 coolo@suse.com
- updated to 3.05
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  3.05  2017-03-12
  - Improved from_string method in Mojo::Pg with search_path support.
* Thu Mar  9 2017 coolo@suse.com
- updated to 3.04
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  3.04  2017-03-08
  - Fixed array reference handling in queries generated with SQL::Abstract.
* Wed Mar  8 2017 coolo@suse.com
- updated to 3.03
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  3.03  2017-03-07
  - Added reset method to Mojo::Pg::PubSub.
* Wed Mar  1 2017 coolo@suse.com
- updated to 3.02
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  3.02  2017-02-18
  - Fixed quoting bugs in queries generated with SQL::Abstract.
* Mon Feb 13 2017 coolo@suse.com
- updated to 3.01
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  3.01  2017-02-12
  - Fixed bug in examples where migrations would not be handled correctly.
* Sun Feb 12 2017 coolo@suse.com
- updated to 3.0
  see /usr/share/doc/packages/perl-Mojo-Pg/Changes
  3.0  2017-02-11
  - Added support for generating queries with SQL::Abstract.
  - Added abstract attribute to Mojo::Pg.
  - Added delete, insert, select and update methods to Mojo::Pg::Database.
* Thu Feb  9 2017 coolo@suse.com
- initial package 2.35
  * created by cpanspec 1.78.08
